@@ -2,8 +2,7 @@ __all__ = ('AssertionBase',)
 
 from scarletio import RichAttributeErrorBaseType
 
-from . import assertion_states as CONDITION_STATES
-from .assertion_states import get_assertion_state_name
+from .assertion_states import ASSERTION_STATE_NONE, get_assertion_state_name
 
 
 class AssertionBase(RichAttributeErrorBaseType):
@@ -17,45 +16,39 @@ class AssertionBase(RichAttributeErrorBaseType):
     """
     __slots__ = ('state',)
     
+    
     def __new__(cls):
         """
         Creates a new condition.
         """
         self = object.__new__(cls)
-        self.state = CONDITION_STATES.NONE
+        self.state = ASSERTION_STATE_NONE
         return self
     
     
-    def _cursed_repr_builder(self):
+    def _build_repr_parts_into(self, into):
         """
         Representation builder helper.
         
-        This method is a generator.
+        Parameters
+        ----------
+        into : `list` of `str`
+            List of strings to build the representation into.
         
-        Examples
-        --------
-        ```
-        for repr_parts in self._cursed_repr_builder():
-            repr_parts.append(', oh no')
-        
-        return ''.join(repr_parts)
-        ```
+        Returns
+        -------
+        into : `list` of `str`
         """
-        repr_parts = ['<', self.__class__.__name__]
-        
-        repr_parts.append(' state=')
-        repr_parts.append(get_assertion_state_name(self.state))
-        
-        yield repr_parts
-        
-        repr_parts.append('>')
+        return into
     
     
     def __repr__(self):
         """Returns the condition's representation."""
-        for repr_parts in self._cursed_repr_builder():
-            pass
-        
+        repr_parts = ['<', self.__class__.__name__]
+        repr_parts.append(' state = ')
+        repr_parts.append(get_assertion_state_name(self.state))
+        repr_parts = self._build_repr_parts_into(repr_parts)
+        repr_parts.append('>')
         return ''.join(repr_parts)
     
     
