@@ -1,4 +1,4 @@
-__all__ = ('AssertionNotContains', 'assert_not_contains', 'assert_not_in')
+__all__ = ('AssertionNotContains',)
 
 from scarletio import copy_docs
 
@@ -17,22 +17,18 @@ class AssertionNotContains(AssertionConditionalBase2Value):
         Exception raised by the condition if any.
     reverse : `bool`
         Whether the condition should be reversed.
-    value_1 : `Any`
+    value_0 : `object`
         First value to assert contains with.
-    value_2 : `Any`
+    value_1 : `object`
         The second value to assert contains with.
     """
     __slots__ = ()
     
     @copy_docs(AssertionConditionalBase2Value.invoke_condition)
     def invoke_condition(self):
-        return self.value_1 not in self.value_2
+        return self.value_0 not in self.value_1
     
     
     @copy_docs(AssertionConditionalBase2Value._get_operation_representation)
     def _get_operation_representation(self):
         return 'not in'
-
-
-assert_not_contains = AssertionNotContains
-assert_not_in = AssertionNotContains
