@@ -1,4 +1,4 @@
-__all__ = ('AssertionNotEquals', 'assert_ne', 'assert_not_eq', 'assert_not_equals')
+__all__ = ('AssertionNotEquals',)
 
 from scarletio import copy_docs
 
@@ -17,23 +17,18 @@ class AssertionNotEquals(AssertionConditionalBase2Value):
         Exception raised by the condition if any.
     reverse : `bool`
         Whether the condition should be reversed.
-    value_1 : `Any`
+    value_0 : `object`
         First value to assert equality with.
-    value_2 : `Any`
+    value_1 : `object`
         The second value to assert equality with.
     """
     __slots__ = ()
     
     @copy_docs(AssertionConditionalBase2Value.invoke_condition)
     def invoke_condition(self):
-        return self.value_1 != self.value_2
+        return self.value_0 != self.value_1
     
     
     @copy_docs(AssertionConditionalBase2Value._get_operation_representation)
     def _get_operation_representation(self):
         return '!='
-
-
-assert_ne = AssertionNotEquals
-assert_not_eq = AssertionNotEquals
-assert_not_equals = AssertionNotEquals
