@@ -1,4 +1,4 @@
-__all__ = ('AssertionNotIdentical', 'assert_is_not', 'assert_not_id', 'assert_not_identical', 'assert_not_is')
+__all__ = ('AssertionNotIdentical',)
 
 from scarletio import copy_docs
 
@@ -17,24 +17,18 @@ class AssertionNotIdentical(AssertionConditionalBase2Value):
         Exception raised by the condition if any.
     reverse : `bool`
         Whether the condition should be reversed.
-    value_1 : `Any`
+    value_0 : `object`
         First value to assert identity with.
-    value_2 : `Any`
+    value_1 : `object`
         The second value to assert identity with.
     """
-    __slots__ = ('value_1', 'value_2',)
+    __slots__ = ()
     
     @copy_docs(AssertionConditionalBase2Value.invoke_condition)
     def invoke_condition(self):
-        return self.value_1 is not self.value_2
+        return self.value_0 is not self.value_1
     
     
     @copy_docs(AssertionConditionalBase2Value._get_operation_representation)
     def _get_operation_representation(self):
         return 'is not'
-
-
-assert_not_id = AssertionNotIdentical
-assert_is_not = AssertionNotIdentical
-assert_not_identical = AssertionNotIdentical
-assert_not_is = AssertionNotIdentical
