@@ -4,7 +4,7 @@ from time import sleep as sync_sleep
 
 from scarletio import copy_docs, EventThread
 
-from ..handle import ResultState
+from ..handling import ResultState
 
 from .constants import ENVIRONMENT_TYPE_COROUTINE
 from .default import DefaultEnvironment
@@ -61,13 +61,18 @@ class ScarletioCoroutineEnvironment(DefaultEnvironment):
         
         try:
             if create_event_loop:
-                event_loop = EventThread(daemon=True, name = 'scarletio.run', start_later=False)
+                event_loop = EventThread(daemon = True, name = 'scarletio.run', start_later = False)
             
-            return event_loop.run(
-                self._run_async(test, positional_parameters, keyword_parameters),
-                timeout = self.timeout,
-            )
-        
+            try:
+                return event_loop.run(
+                    self._run_async(test, positional_parameters, keyword_parameters),
+                    timeout = self.timeout,
+                )
+            except KeyboardInterrupt as exception:
+                # In case it is frozen lets provide a better output. Better than nothing.
+                raise KeyboardInterrupt(
+                    f'`{type(self).__name__}.run` interrupted while running {test!r}.'
+                ) from exception
         finally:
             if create_event_loop:
                 if (event_loop is not None):
@@ -84,11 +89,11 @@ class ScarletioCoroutineEnvironment(DefaultEnvironment):
         
         Parameters
         ----------
-        test : `callable`
+        test : `FunctionType`
             The test to call
-        positional_parameters : `list` of `Any`
+        positional_parameters : `list` of `object`
             Positional parameters to call the test with.
-        keyword_parameters : `dict` of (`str`, `Any`) items
+        keyword_parameters : `dict` of (`str`, `object`) items
             Keyword parameters to call the test with.
         
         Returns
@@ -98,13 +103,10 @@ class ScarletioCoroutineEnvironment(DefaultEnvironment):
         """
         try:
             returned_value = await test(*positional_parameters, **keyword_parameters)
-        except BaseException as err:
-            returned_value = None
-            raised_exception = err
-        else:
-            raised_exception = None
+        except BaseException as raised_exception:
+            return ResultState().with_raise(raised_exception)
         
-        return ResultState(returned_value, raised_exception)
+        return ResultState().with_return(returned_value)
     
     
     @copy_docs(DefaultEnvironment.__repr__)
@@ -131,7 +133,7 @@ class ScarletioCoroutineEnvironment(DefaultEnvironment):
         
         repr_parts.append('>')
         return ''.join(repr_parts)
-
+    
     
     @copy_docs(DefaultEnvironment.shutdown)
     def shutdown(self):
