@@ -1,11 +1,17 @@
+from .rendering_helpers import *
+
 from .base import *
+from .colors import *
 from .default import *
 from .default_output_writer import *
 from .text_styling import *
 
 
 __all__ = (
+    *rendering_helpers.__all__,
+    
     *base.__all__,
+    *colors.__all__,
     *default.__all__,
     *default_output_writer.__all__,
     *text_styling.__all__,
