@@ -1,21 +1,21 @@
 __all__ = ('create_default_event_handler_manager',)
 
-from scarletio import RichAttributeErrorBaseType, create_ansi_format_code
-
-from ..events import FileLoadDoneEvent, FileRegistrationDoneEvent, FileTestingDoneEvent, TestDoneEvent, TestingEndEvent
+from scarletio import RichAttributeErrorBaseType, export
 
+from ..events import (
+    FileLoadDoneEvent, FileRegistrationDoneEvent, FileTestingDoneEvent, SourceLoadFailureEvent, TestDoneEvent,
+    TestingEndEvent
+)
 from .base import EventHandlerManager
+from .colors import COLOR_FAIL, COLOR_PASS, COLOR_SKIP, COLOR_UNKNOWN
 from .default_output_writer import OutputWriter
+from .rendering_helpers.load_failure_rendering import render_load_failure_exception
+from .rendering_helpers.result_modifier_parameters import build_result_modifier_parameters
+from .rendering_helpers.writers import write_load_failure, write_result_failing, write_result_informal
 from .text_styling import style_text
 
 
-COLOR_FAIL = create_ansi_format_code(foreground_color = (255, 0, 0))
-COLOR_PASS = create_ansi_format_code(foreground_color = (0, 255, 0))
-COLOR_SKIP = create_ansi_format_code(foreground_color = (0, 255, 255))
-COLOR_UNKNOWN = create_ansi_format_code(foreground_color = (255, 0, 255))
-COLOR_RESET = create_ansi_format_code()
-
-
+@export
 def create_default_event_handler_manager():
     """
     Creates a default event handler manager if non is given.
@@ -32,6 +32,7 @@ def create_default_event_handler_manager():
     event_handler_manager.events(output_formatter.test_done)
     event_handler_manager.events(output_formatter.file_testing_done)
     event_handler_manager.events(output_formatter.testing_end)
+    event_handler_manager.events(output_formatter.source_load_failure)
     
     return event_handler_manager
 
@@ -43,13 +44,13 @@ class DefaultEventFormatter(RichAttributeErrorBaseType):
     Attributes
     ----------
     rendered_entries : `set` of ``FileSystemEntry``
-        The rendered entries by the
+        The  already rendered file system entries.
     output_writer : ``OutputWriter``
         The output writer to write the output with.
     """
     __slots__ = ('rendered_entries', 'output_writer',)
     
-    def __new__(cls, output_writer=None):
+    def __new__(cls, output_writer = None):
         """
         Creates a new default event formatter.
         
@@ -69,7 +70,7 @@ class DefaultEventFormatter(RichAttributeErrorBaseType):
     
     def __repr__(self):
         """Returns the output formatter representation."""
-        return f'<{self.__class__.__name__} output_writer={self.output_writer!r}>'
+        return f'<{self.__class__.__name__} output_writer = {self.output_writer!r}>'
     
     
     def file_registration_done(self, event: FileRegistrationDoneEvent):
@@ -109,7 +110,7 @@ class DefaultEventFormatter(RichAttributeErrorBaseType):
             self.output_writer.write_line(''.join(message_parts))
     
     
-    def _maybe_render_test_file_into(self, into, entry, *, name=None):
+    def _maybe_render_test_file_into(self, into, entry, *, name = None):
         """
         Helpers method for rendering file structure tree.
         
@@ -136,7 +137,7 @@ class DefaultEventFormatter(RichAttributeErrorBaseType):
                 into = sub_entry.render_into(into)
                 rendered_entries.add(sub_entry)
             
-            into = entry.render_into(into, name=name)
+            into = entry.render_into(into, name = name)
             rendered_entries.add(entry)
         
         return into
@@ -151,23 +152,31 @@ class DefaultEventFormatter(RichAttributeErrorBaseType):
         event : ``TestDoneEvent``
             The dispatched event.
         """
-        test_file = event.result_group.case.get_test_file()
+        test_file = event.result.case.get_test_file()
         if (test_file is None):
             # Should not happen
             return
         
         message_parts = self._maybe_render_test_file_into([], test_file.entry)
         
-        result_group = event.result_group
-        if result_group.is_skipped():
+        result = event.result
+        if result.is_skipped():
             keyword = 'S'
             foreground = COLOR_SKIP
         
-        elif result_group.is_passed():
+        elif result.is_conflicted():
+            keyword = 'C'
+            foreground = COLOR_FAIL
+        
+        elif result.is_informal():
+            keyword = 'I'
+            foreground = COLOR_PASS
+        
+        elif result.is_passed():
             keyword = 'P'
             foreground = COLOR_PASS
         
-        elif result_group.is_failed():
+        elif result.is_failed():
             keyword = 'F'
             foreground = COLOR_FAIL
         
@@ -175,16 +184,16 @@ class DefaultEventFormatter(RichAttributeErrorBaseType):
             keyword = '?'
             foreground = COLOR_UNKNOWN
         
+        result_modifiers = build_result_modifier_parameters(result.get_modifier_parameters())
         message_parts = test_file.entry.render_custom_sub_directory_into(
             message_parts,
-            style_text(f'{keyword} {result_group.case.name}', foreground),
-            result_group.case.is_last(),
+            style_text(f'{keyword} {result.case.name}{result_modifiers}', foreground),
+            result.is_last() and result.case.is_last(),
         )
         
         self.output_writer.write_line(''.join(message_parts))
     
-
-
+    
     def file_testing_done(self, event: FileTestingDoneEvent):
         """
         Called when all tests of a file is done
@@ -214,29 +223,19 @@ class DefaultEventFormatter(RichAttributeErrorBaseType):
         context = event.context
         
         load_failures = context.get_file_load_failures()
-        
         for load_failure in load_failures:
-            message = ''.join([
-                'Exception occurred while loading:\n',
-                load_failure.path,
-                '\n\n',
-                load_failure.exception_message,
-            ])
-            
-            output_writer.write_line(message)
-            output_writer.write_break_line()
+            write_load_failure(output_writer, load_failure)
         
-        
-        for result_group in context.iter_failed_result_groups():
-            for failure_message in result_group.iter_failure_messages():
-                output_writer.write_line(failure_message)
-                output_writer.write_break_line()
+        for result in context.iter_failed_results():
+            write_result_failing(output_writer, result)
         
         failed_count = context.get_failed_test_count()
         failed_message_part = f'{failed_count} failed'
         if failed_count:
             failed_message_part = style_text(failed_message_part, COLOR_FAIL)
-        
+        else:
+            for result in context.iter_informal_results():
+                write_result_informal(output_writer, result)
         
         skipped_count = context.get_skipped_test_count()
         skipped_message_part = f'{skipped_count} skipped'
@@ -255,3 +254,19 @@ class DefaultEventFormatter(RichAttributeErrorBaseType):
             output_writer.write(
                 style_text(f' | {len(load_failures)} files failed to load', COLOR_FAIL))
         output_writer.end_line()
+    
+    
+    def source_load_failure(self, event: SourceLoadFailureEvent):
+        """
+        Called when a source is failed to load.
+        
+        Parameters
+        ----------
+        event : ``TestDoneEvent``
+            The dispatched event.
+        """
+        output_writer = self.output_writer
+        output_writer.write_line(f'Failed to import {event.source} from {event.context.runner._source_directory}')
+        output_writer.write_break_line()
+        output_writer.write(render_load_failure_exception(event.exception))
+        output_writer.end_line()
