@@ -19,8 +19,8 @@ class OutputWriter(RichAttributeErrorBaseType):
         Whether the last written line was a break line.
     _last_write_ended_with_linebreak : `bool`
         Whether the last write ended with a linebreak.
-    file : `Any`
-        Any writable object.
+    file : `io-like`
+        object writable object.
     """
     def __new__(cls, file = None):
         """
@@ -28,7 +28,7 @@ class OutputWriter(RichAttributeErrorBaseType):
         
         Parameters
         ----------
-        file : `None`, `Any` = `None`, Optional
+        file : `None`, `io-like` = `None`, Optional
             Writable object. If not given defaults to `sys.stdout`.
         """
         if file is None:
@@ -41,7 +41,7 @@ class OutputWriter(RichAttributeErrorBaseType):
         return self
     
     
-    def write_break_line(self, character="="):
+    def write_break_line(self, character = '='):
         """
         Writes a break line.
         
