@@ -4,10 +4,12 @@ from .file_load_done import *
 from .file_registration import *
 from .file_registration_done import *
 from .file_testing_done import *
+from .source_load_failure import *
 from .test_done import *
 from .testing_end import *
 from .testing_start import *
 
+
 __all__ = (
     *base.__all__,
     *constants.__all__,
@@ -15,6 +17,7 @@ __all__ = (
     *file_registration.__all__,
     *file_registration_done.__all__,
     *file_testing_done.__all__,
+    *source_load_failure.__all__,
     *test_done.__all__,
     *testing_end.__all__,
     *testing_start.__all__,
