@@ -1,11 +1,12 @@
 __all__ = ('TestFile', )
 
-import sys
+from sys import modules
+from types import FunctionType
 
 from scarletio import RichAttributeErrorBaseType
 
 from ..environment import apply_environments_for_file_at
-from ..utils import get_short_path_repr
+from ..helpers.path_repr import get_short_path_repr
 from ..test_case import TestCase
 from ..wrappers import WrapperBase
 
@@ -42,7 +43,7 @@ def is_test(name, value):
     ----------
     name : `str`
         The name of a a variable.
-    value : `Any`
+    value : `object`
         The variable's value.
     
     Returns
@@ -55,7 +56,10 @@ def is_test(name, value):
     if isinstance(value, WrapperBase):
         return value.has_bound_test()
     
-    return callable(value)
+    if isinstance(value, FunctionType):
+        return True
+    
+    return False
 
 
 def _test_case_sort_key(test_case):
@@ -84,7 +88,7 @@ class TestFile(RichAttributeErrorBaseType):
         If loading the test file fails, this attribute is set to details about the occurred exception.
     _module : `None`, `ModuleType`
         The module of the test file. Only set when the first call is made to it.
-    _result_groups : `None`, `list` of ``ResultGroup``
+    _results : `None`, `list` of ``Result``
         Results of already ran tests.
     _sub_files : `None`, `list` of ``TestFile``
         Sub files if we are a directory.
@@ -105,13 +109,14 @@ class TestFile(RichAttributeErrorBaseType):
         - ``.get_load_failure``
         - ``.is_directory``
         - ``.is_loaded``
+        - ``.has_failed_test``
     
     - Iterators
     
-        - ``.iter_result_groups``
-        - ``.iter_passed_result_groups``
-        - ``.iter_skipped_result_groups``
-        - ``.iter_failed_result_groups``
+        - ``.iter_results``
+        - ``.iter_passed_results``
+        - ``.iter_skipped_results``
+        - ``.iter_failed_results``
         - ``.iter_sub_files``
     
     - Counters
@@ -134,7 +139,7 @@ class TestFile(RichAttributeErrorBaseType):
         - ``.iter_test_files``
     """
     __slots__ = (
-        '__weakref__', '_load_failure', '_module', '_result_groups', '_sub_files', '_test_cases', 'entry', 'import_route'
+        '__weakref__', '_load_failure', '_module', '_results', '_sub_files', '_test_cases', 'entry', 'import_route'
     )
     
     def __new__(cls, entry):
@@ -164,7 +169,7 @@ class TestFile(RichAttributeErrorBaseType):
         self = object.__new__(cls)
         self._load_failure = None
         self._module = None
-        self._result_groups = None
+        self._results = None
         self._sub_files = None
         self._test_cases = None
         self.entry = entry
@@ -189,7 +194,7 @@ class TestFile(RichAttributeErrorBaseType):
         """Returns the representation of a test file."""
         repr_parts = ['<', self.__class__.__name__]
         
-        repr_parts.append(' path=')
+        repr_parts.append(' path = ')
         repr_parts.append(get_short_path_repr(self.path))
         
         repr_parts.append('>')
@@ -249,7 +254,7 @@ class TestFile(RichAttributeErrorBaseType):
             self._load_failure = TestFileLoadFailure(self, err)
             return False
         
-        module = sys.modules[import_route]
+        module = modules[import_route]
         self._module = module
         return True
     
@@ -376,44 +381,43 @@ class TestFile(RichAttributeErrorBaseType):
         
         Yields
         ------
-        result_group : ``ResultGroup``
+        result : ``Result``
         """
         if self.is_directory():
             return
         
-        result_groups = self._result_groups
-        if (result_groups is not None):
-            return (yield from result_groups)
+        results = self._results
+        if (results is not None):
+            return (yield from results)
         
         environment_manager = apply_environments_for_file_at(environment_manager, self.path)
         for test_case in self.iter_test_cases():
-            result_group = test_case.invoke(environment_manager)
-            
-            if (result_groups is None):
-                result_groups = []
-                self._result_groups = result_groups
-            
-            result_groups.append(result_group)
-            
-            yield result_group
+            for result in test_case.iter_invoke(environment_manager):
+                if (results is None):
+                    results = []
+                    self._results = results
+                
+                results.append(result)
+                
+                yield result
     
     
-    def iter_result_groups(self):
+    def iter_results(self):
         """
-        Iterates over the result groups of the test file.
+        Iterates over the results of the test file.
         
         This method is an iterable generator.
         
         Yields
         ------
-        result_group : ``ResultGroup``
+        result : ``Result``
         """
-        result_groups = self._result_groups
-        if (result_groups is not None):
-            yield from result_groups
+        results = self._results
+        if (results is not None):
+            yield from results
         
         for sub_file in self.iter_sub_files():
-            yield from sub_file.iter_result_groups()
+            yield from sub_file.iter_results()
     
     
     def get_test_case_count(self):
@@ -444,11 +448,11 @@ class TestFile(RichAttributeErrorBaseType):
         -------
         ran_test_count : `int`
         """
-        result_groups = self._result_groups
-        if (result_groups is None):
+        results = self._results
+        if (results is None):
             ran_test_count = 0
         else:
-            ran_test_count = len(result_groups)
+            ran_test_count = len(results)
         
         for sub_file in self.iter_sub_files():
             ran_test_count += sub_file.get_ran_test_count()
@@ -456,49 +460,64 @@ class TestFile(RichAttributeErrorBaseType):
         return ran_test_count
     
     
-    def iter_passed_result_groups(self):
+    def iter_passed_results(self):
         """
-        Iterates over the passed result groups of the test file.
+        Iterates over the passed results of the test file.
         
         This method is an iterable generator.
         
         Yields
         ------
-        result_group : ``ResultGroup``
+        result : ``Result``
         """
-        for result_group in self.iter_result_groups():
-            if result_group.is_passed():
-                yield result_group
+        for result in self.iter_results():
+            if result.is_passed():
+                yield result
     
     
-    def iter_skipped_result_groups(self):
+    def iter_skipped_results(self):
         """
-        Iterates over the skipped result groups of the test file.
+        Iterates over the skipped results of the test file.
         
         This method is an iterable generator.
         
         Yields
         ------
-        result_group : ``ResultGroup``
+        result : ``Result``
         """
-        for result_group in self.iter_result_groups():
-            if result_group.is_skipped():
-                yield result_group
+        for result in self.iter_results():
+            if result.is_skipped():
+                yield result
     
     
-    def iter_failed_result_groups(self):
+    def iter_failed_results(self):
         """
-        Iterates over the failed result groups of the test file.
+        Iterates over the failed results of the test file.
         
         This method is an iterable generator.
         
         Yields
         ------
-        result_group : ``ResultGroup``
+        result : ``Result``
         """
-        for result_group in self.iter_result_groups():
-            if result_group.is_failed():
-                yield result_group
+        for result in self.iter_results():
+            if result.is_failed():
+                yield result
+    
+    
+    def iter_informal_results(self):
+        """
+        Iterates over the informal results of the test file.
+        
+        This method is an iterable generator.
+        
+        Yields
+        ------
+        result : ``Result``
+        """
+        for result in self.iter_results():
+            if result.is_informal():
+                yield result
     
     
     def get_passed_test_count(self):
@@ -509,7 +528,7 @@ class TestFile(RichAttributeErrorBaseType):
         -------
         passed_test_count : `int`
         """
-        return sum(result_group.is_passed() for result_group in self.iter_result_groups())
+        return sum(result.is_passed() for result in self.iter_results())
     
     
     def get_skipped_test_count(self):
@@ -520,7 +539,7 @@ class TestFile(RichAttributeErrorBaseType):
         -------
         passed_test_count : `int`
         """
-        return sum(result_group.is_skipped() for result_group in self.iter_result_groups())
+        return sum(result.is_skipped() for result in self.iter_results())
     
     
     def get_failed_test_count(self):
@@ -531,7 +550,18 @@ class TestFile(RichAttributeErrorBaseType):
         -------
         passed_test_count : `int`
         """
-        return sum(result_group.is_failed() for result_group in self.iter_result_groups())
+        return sum(result.is_failed() for result in self.iter_results())
+    
+    
+    def has_failed_test(self):
+        """
+        Returns whether there were any failed tests.
+        
+        Returns
+        -------
+        has_failed_tests : `bool`
+        """
+        return any(result.is_failed() for result in self.iter_results())
     
     
     def feed_sub_file(self, sub_file):
