@@ -2,44 +2,61 @@ __all__ = ('TestRunner', 'run_tests_in')
 
 import sys
 from functools import partial as partial_func
-from os.path import isfile as is_file, split as split_paths
-from sys import path as system_paths, modules as system_modules
+from os import getcwd as get_current_working_directory
+from os.path import sep as PATH_SEPARATOR
 
-from scarletio import RichAttributeErrorBaseType, render_exception_into
+from scarletio import RichAttributeErrorBaseType, include, render_exception_into
 
 from ... import __package__ as PACKAGE_NAME
+from ...return_codes import (
+    RETURN_CODE_FAILURE, RETURN_CODE_SUCCESS, RETURN_CODE_TEST_RUNNER_STOPPED, RETURN_CODE_UNSET
+)
 
 from ..environment import EnvironmentManager
 from ..events import (
-    FileLoadDoneEvent, FileRegistrationEvent, FileRegistrationDoneEvent, FileTestingDoneEvent, TestDoneEvent,
-    TestingEndEvent, TestingStartEvent
+    FileLoadDoneEvent, FileRegistrationEvent, FileRegistrationDoneEvent, FileTestingDoneEvent, SourceLoadFailureEvent,
+    TestDoneEvent, TestingEndEvent, TestingStartEvent
 )
-from ..event_handling import create_default_event_handler_manager
 from ..file import FileSystemEntry, iter_collect_test_files_in
 
 from .context import RunnerContext
 
 
+create_default_event_handler_manager = include('create_default_event_handler_manager')
+
+
 def setup_test_library_import():
     """
     Setups test directory import if not on path instead running it relatively.
-    
-    Returns
-    -------
-    added_system_path : `None`, `str`
-        Returns the added system path if any.
     """
     split = PACKAGE_NAME.split('.')
     if len(split) <= 1:
         return None
     
     module = __import__(PACKAGE_NAME)
+    
     for directory_name in split[1:]:
         module = module.__dict__[directory_name]
     
-    system_modules[split[-1]] = module
+    sys.modules[split[-1]] = module
 
 
+def _add_to_system_path_callback(path, runner):
+    """
+    Removes the given path from `sys.path`.
+    
+    Parameters
+    ----------
+    path : `str`
+        The path to remove.
+    runner : ``TestRunner``
+        The respective test runner.
+    """
+    if path not in sys.path:
+        sys.path.append(path)
+        
+    
+
 def _remove_from_system_path_callback(path, runner):
     """
     Removes the given path from `sys.path`.
@@ -52,25 +69,19 @@ def _remove_from_system_path_callback(path, runner):
         The respective test runner.
     """
     try:
-        system_paths.remove(path)
+        sys.path.remove(path)
     except ValueError:
         pass
 
 
-def _ignore_test_call_frame(file_name, name, line_number, line):
+def _ignore_test_call_frame(frame):
     """
     Ignores test runner frames when rendering event handler exception
     
     Parameters
     ----------
-    file_name : `str`
-        The frame's respective file's name.
-    name : `str`
-        The frame's respective function's name.
-    line_number : `int`
-        The line's index where the exception occurred.
-    line : `str`
-        The frame's respective stripped line.
+    frame : ``FrameProxyBase``
+        The frame to check.
     
     Returns
     -------
@@ -79,6 +90,10 @@ def _ignore_test_call_frame(file_name, name, line_number, line):
     """
     should_show_frame = True
     
+    file_name = frame.file_name
+    name = frame.name
+    line = frame.line
+    
     if file_name == __file__:
         if name == 'run':
             if line == 'event_handler(event)':
@@ -111,7 +126,7 @@ def _render_event_exception(event_handler, event, err):
         '\n\n'
     ]
     
-    render_exception_into(err, exception_message_parts, filter=_ignore_test_call_frame)
+    render_exception_into(err, exception_message_parts, filter = _ignore_test_call_frame)
     
     return ''.join(exception_message_parts)
 
@@ -120,10 +135,14 @@ class TestRunner(RichAttributeErrorBaseType):
     """
     Attributes
     ----------
-    _base_path : `str`
-        The path to run tests from.
-    _path_parts : `list` of `str`   
+    _path_parts : `None | list<str>`
         Added path parts to specify from which which directory we want to collect the tests from.
+    _return_code : `int`
+        The return code of the test runner.
+    _source_directory : `str`
+        The path to run tests from.
+    _sources : `set<str>`
+        Sources to import before executing any test.
     _stopped : `bool`
         Whether testing is stopped.
     _teardown_callbacks : `None`, `list` of `callable`
@@ -138,29 +157,39 @@ class TestRunner(RichAttributeErrorBaseType):
     - ``.run``
     - ``.stop``
     - ``.add_teardown_callback``
+    - ``.get_return_code``
+    - ``.set_return_code``
     """
     __slots__ = (
-        '_base_path', '_path_parts', '_stopped', '_teardown_callbacks', 'environment_manager', 'event_handler_manager'
+        '_path_parts', '_return_code', '_source_directory', '_sources', '_stopped', '_teardown_callbacks',
+        'environment_manager', 'event_handler_manager'
     )
     
-    def __new__(cls, base_path, path_parts=None, *, environment_manager=None, event_handler_manager=None):
+    def __new__(
+        cls, source_directory, sources, path_parts = None, *, environment_manager = None, event_handler_manager = None
+    ):
         """
+        Creates a new test runner instance.
+        
         Parameters
         ----------
-        base_path : `str`
+        source_directory : `str`
             The path to run tests from.
-        path_parts : `None`, `list` of `str` = `None`, Optional
+        sources : `set<str>`
+            Sources to import before executing any test.
+        path_parts : `None | list<str>` = `None`, Optional
             Added path parts to specify from which which directory we want to collect the tests from.
         environment_manager : `None`, ``EnvironmentManager`` = `None`, Optional (Keyword only)
             Testing environment manager.
         event_handler_manager : `None`, ``EventHandlerManager`` = `None`, Optional (Keyword only)
             Event handler container.
         """
-        if path_parts is None:
-            path_parts = []
-        else:
-            path_parts = path_parts.copy()
-        
+        if (path_parts is not None):
+            if path_parts:
+                path_parts = path_parts.copy()
+            else:
+                path_parts = None
+            
         if environment_manager is None:
             environment_manager = EnvironmentManager()
         
@@ -170,8 +199,10 @@ class TestRunner(RichAttributeErrorBaseType):
             event_handler_manager = create_default_event_handler_manager()
         
         self = object.__new__(cls)
-        self._base_path = base_path
         self._path_parts = path_parts
+        self._return_code = RETURN_CODE_UNSET
+        self._source_directory = source_directory
+        self._sources = sources
         self._stopped = False
         self._teardown_callbacks = None
         self.environment_manager = environment_manager
@@ -183,24 +214,36 @@ class TestRunner(RichAttributeErrorBaseType):
         """
         Setups the test dependencies.
         """
-        base_path = self._base_path
-        path_parts = self._path_parts
+        # Add source directory to sys.path if not there
+        source_directory = self._source_directory
         
-        if is_file(base_path):
-            base_path, file_name = split_paths(base_path)
-            path_parts.insert(0, file_name)
-        
-        if base_path in system_paths:
-            base_path_in_system_paths = True
+        if source_directory in sys.path:
+            source_directory_in_system_paths = True
         else:
-            system_paths.append(base_path)
-            base_path_in_system_paths = False
+            sys.path.append(source_directory)
+            source_directory_in_system_paths = False
         
-        self._base_path = base_path
-        self._path_parts = path_parts
+        if not source_directory_in_system_paths:
+            self.add_teardown_callback(partial_func(_remove_from_system_path_callback, source_directory))
         
-        if base_path_in_system_paths:
-            self.add_teardown_callback(partial_func(_remove_from_system_path_callback, base_path))
+        # Remove working directory from sys.path if under source directory
+        working_directory = get_current_working_directory()
+        if (
+            working_directory in sys.path and
+            len(working_directory) > len(source_directory) and
+            working_directory.startswith(source_directory) and
+            working_directory[len(source_directory)] == PATH_SEPARATOR
+        ):
+            working_directory_under_source = True
+            try:
+                sys.path.remove(working_directory)
+            except ValueError:
+                pass
+        else:
+            working_directory_under_source = False
+        
+        if not working_directory_under_source:
+            self.add_teardown_callback(partial_func(_add_to_system_path_callback, working_directory))
         
         setup_test_library_import()
     
@@ -251,19 +294,38 @@ class TestRunner(RichAttributeErrorBaseType):
         ------
         event : ``EventBase``
         """
-
+        context = None
+        
         try:
             # Setup
             self._setup()
             
-            context = RunnerContext(self, FileSystemEntry(*split_paths(self._base_path), self._path_parts))
+            # Build context.
+            path_parts = self._path_parts
+            if path_parts is None:
+                file_system_entries = [
+                    FileSystemEntry(self._source_directory, source, None) for source in self._sources
+                ]
+            else:
+                file_system_entries = [FileSystemEntry(self._source_directory, path_parts[0], path_parts[1:])]
+            
+            context = RunnerContext(self, file_system_entries)
+            
+            # Import plugins.
+            for source in self._sources:
+                try:
+                    __import__(source)
+                except BaseException as err:
+                    yield SourceLoadFailureEvent(context, source, err)
+                    return
             
             yield TestingStartEvent(context)
             
             # Collect test files
-            for test_file in iter_collect_test_files_in(context.file_system_entry):
-                context.register_file(test_file)
-                yield FileRegistrationEvent(context, test_file)
+            for file_system_entry in context.file_system_entries:
+                for test_file in iter_collect_test_files_in(file_system_entry):
+                    context.register_file(test_file)
+                    yield FileRegistrationEvent(context, test_file)
             
             yield FileRegistrationDoneEvent(context)
             
@@ -288,13 +350,21 @@ class TestRunner(RichAttributeErrorBaseType):
                         # Run test file if loaded successfully
                         if test_file.is_loaded_with_success():
                             
-                            for result_group in test_file.iter_invoke_test_cases(self.environment_manager):
-                                yield TestDoneEvent(context, result_group)
+                            for result in test_file.iter_invoke_test_cases(self.environment_manager):
+                                yield TestDoneEvent(context, result)
                             
                             yield FileTestingDoneEvent(context, test_file)
             
             yield TestingEndEvent(context)
         
+        except GeneratorExit:
+            self.set_return_code(RETURN_CODE_TEST_RUNNER_STOPPED)
+            raise
+        
+        else:
+            if (context is not None):
+                self.set_return_code(RETURN_CODE_FAILURE if context.has_any_failure() else RETURN_CODE_SUCCESS)
+        
         finally:
             self._teardown()
     
@@ -302,9 +372,13 @@ class TestRunner(RichAttributeErrorBaseType):
     def run(self):
         """
         Runs the tests of the test runner.
+        
+        Returns
+        -------
+        return_code : `int`
         """
         if self._stopped:
-            return
+            return self.get_return_code()
         
         event_handler_manager = self.event_handler_manager
         
@@ -312,11 +386,16 @@ class TestRunner(RichAttributeErrorBaseType):
             for event_handler in event_handler_manager.iter_handlers_for_event(event):
                 try:
                     event_handler(event)
+                except (KeyboardInterrupt, SystemExit):
+                    raise
+                
                 except BaseException as err:
                     sys.stderr.write(_render_event_exception(event_handler, event, err))
             
             if self._stopped:
                 break
+        
+        return self.get_return_code()
     
     
     def stop(self):
@@ -324,17 +403,53 @@ class TestRunner(RichAttributeErrorBaseType):
         Stops the testing step loop.
         """
         self._stopped = True
+        self.set_return_code(RETURN_CODE_TEST_RUNNER_STOPPED)
+    
+    
+    def get_return_code(self):
+        """
+        Gets the set return code.
+        
+        Returns
+        -------
+        return_code : `int`
+        """
+        return_code = self._return_code
+        if return_code == RETURN_CODE_UNSET:
+            return_code = RETURN_CODE_SUCCESS
+        
+        return return_code
+    
+    
+    def set_return_code(self, return_code):
+        """
+        Sets the test runner's return code if not set yet.
+        
+        Parameters
+        ----------
+        return_code : `int`
+            Return code to set.
+        """
+        if self._return_code == RETURN_CODE_UNSET:
+            self._return_code = return_code
 
 
-def run_tests_in(base_path, path_parts):
+def run_tests_in(source_directory, sources, test_collection_route):
     """
-    Runs tests from the given `base_path` and collects them the added `path_parts`.
+    Runs tests from the given `source_directory` and collects them from the given `test_collection_route`.
+    Or from `sources` if not specified.
     
     Parameters
     ----------
-    base_path : `str`
-        The path to run tests from.
-    path_parts : `list` of `str`
+    source_directory : `str`
+        The path to import the sources from.
+    sources : `set<str>`
+        Sources to import before executing any test.
+    test_collection_route : `None | list<str>`
         Added path parts to specify from which which directory we want to collect the tests from.
+    
+    Returns
+    -------
+    return_code : `int`
     """
-    TestRunner(base_path, path_parts).run()
+    return TestRunner(source_directory, sources, test_collection_route).run()
