@@ -4,9 +4,9 @@ import reprlib
 
 from scarletio import RichAttributeErrorBaseType, WeakReferer
 
-from .handle import Handle
-from .helpers import hash_object
-from .result import ResultGroup
+from .handling import Handle
+from .helpers.hashing import hash_object
+from .result import Result
 from .wrappers import WrapperBase
 
 
@@ -20,7 +20,7 @@ class TestCase(RichAttributeErrorBaseType):
         The parent test file of the case.
     name : `str`
         The test's name.
-    test : `callable`, ``WrapperBase``
+    test : `FunctionType`, ``WrapperBase``
         The test itself, or the wrapped test.
     wrapper : `None`, ``WrapperBase``
         Wrappers containing the test if any.    
@@ -37,7 +37,7 @@ class TestCase(RichAttributeErrorBaseType):
             The parent test file.
         name : `str`
             The test's name.
-        test : `callable`, ``WrapperBase``
+        test : `FunctionType`, ``WrapperBase``
             The test itself, or the wrapped test.
         """
         if isinstance(test, WrapperBase):
@@ -81,22 +81,22 @@ class TestCase(RichAttributeErrorBaseType):
         """Returns the test case's representation."""
         repr_parts = ['<', self.__class__.__name__]
         
-        repr_parts.append(' name=')
+        repr_parts.append(' name = ')
         repr_parts.append(repr(self.name))
         
-        repr_parts.append(', test=')
+        repr_parts.append(', test = ')
         repr_parts.append(reprlib.repr(self.test))
         
         wrapper = self.wrapper
         if (wrapper is not None):
-            repr_parts.append(', wrapper=')
+            repr_parts.append(', wrapper = ')
             repr_parts.append(repr(self.wrapper))
         
         if self.do_skip():
             repr_parts.append(', skipped')
         
-        if self.do_revert():
-            repr_parts.append(', reverted')
+        if self.do_reverse():
+            repr_parts.append(', reversed')
         
         repr_parts.append('>')
         return ''.join(repr_parts)
@@ -117,19 +117,19 @@ class TestCase(RichAttributeErrorBaseType):
         return wrapper.do_skip()
     
     
-    def do_revert(self):
+    def do_reverse(self):
         """
-        Returns whether the test's result should be reverted.
+        Returns whether the test's result should be reversed.
         
         Returns
         -------
-        do_revert : `bool`
+        do_reverse : `bool`
         """
         wrapper = self.wrapper
         if wrapper is None:
             return False
         
-        return wrapper.do_revert()
+        return wrapper.do_reverse()
     
     
     def check_conflicts(self):
@@ -145,32 +145,36 @@ class TestCase(RichAttributeErrorBaseType):
             return wrapper.check_conflicts()
     
     
-    def invoke(self, environment_manager):
+    def iter_invoke(self, environment_manager):
         """
-        Invokes the test case.
+        Invokes the test case yielding the results of it.
+        
+        This method is an iterable generator.
         
         Parameters
         ----------
         environment_manager : ``EnvironmentManager``
             Testing environment manager.
         
-        Returns
+        Yields
         -------
-        test_result : ``Result``
+        result : ``Result``
         """
-        test_result_group = ResultGroup(self)
         conflict = self.check_conflicts()
         if (conflict is not None):
-            return test_result_group.with_conflict(conflict)
+            yield Result(self).with_conflict(conflict)
+            return
         
         if self.do_skip():
-            return test_result_group.as_skipped()
+            yield Result(self).as_skipped()
+            return
         
-        for handler in self._iter_handles():
-            test_result = handler.invoke(environment_manager)
-            test_result_group = test_result_group.with_result(test_result)
-        
-        return test_result_group
+        handles = [*self._iter_handles()]
+        for handle, index in zip(handles, reversed(range(len(handles)))):
+            result = handle.invoke(environment_manager)
+            if index:
+                result = result.as_continuous()
+            yield result
     
     
     def _iter_handles(self):
@@ -199,18 +203,20 @@ class TestCase(RichAttributeErrorBaseType):
             
             wrappers = [wrapper for wrapper in wrapper.iter_wrappers() if not wrapper.is_ignored_when_testing()]
             
-            while wrappers:
-                wrapper_to_check = wrappers.pop()
-                wrapper_group = [wrapper_to_check]
+            for initial_wrapper in wrappers:
+                wrapper_group = [initial_wrapper]
                 
                 for wrapper in wrappers:
-                    if wrapper.is_mutually_exclusive_with(wrapper_to_check):
+                    if wrapper in wrapper_group:
                         continue
                     
-                    if wrapper_to_check.is_mutually_exclusive_with(wrapper):
+                    if any(wrapper.is_mutually_exclusive_with(wrapper_to_check) for wrapper_to_check in wrapper_group):
                         continue
                     
-                    wrapper_group.append(wrapper_to_check)
+                    if any(wrapper_to_check.is_mutually_exclusive_with(wrapper) for wrapper_to_check in wrapper_group):
+                        continue
+                    
+                    wrapper_group.append(wrapper)
                     continue
                 
                 wrapper_group = frozenset(wrapper_group)
@@ -283,4 +289,3 @@ class TestCase(RichAttributeErrorBaseType):
             return True
         
         return False
-
