@@ -1,9 +1,11 @@
 __all__ = ('WrapperBase', )
 
-from ..helpers import hash_object
+from types import FunctionType
 
 from scarletio import RichAttributeErrorBaseType, include
 
+from ..helpers.hashing import hash_object
+
 
 WrapperChainer = include('WrapperChainer')
 
@@ -14,7 +16,7 @@ class WrapperBase(RichAttributeErrorBaseType):
     
     Attributes
     ----------
-    wrapped : `None`, `Any`
+    wrapped : `None`, ``WrapperBase``, `FunctionType`
         The wrapped test.
     """
     __slots__ = ('wrapped', )
@@ -34,7 +36,7 @@ class WrapperBase(RichAttributeErrorBaseType):
         
         Parameters
         ----------
-        to_wrap : `Any`
+        to_wrap : `object`
             The object to wrap. It can be either a function or an another wrapper.
         
         Returns
@@ -48,7 +50,7 @@ class WrapperBase(RichAttributeErrorBaseType):
             Wrapper already called.
         """
         if to_wrap is None:
-            raise RuntimeError(f'Cannot wrap `None`; self={self!r}.')
+            raise RuntimeError(f'Cannot wrap `None`; self = {self!r}.')
         
         
         wrapped = self.wrapped
@@ -80,6 +82,12 @@ class WrapperBase(RichAttributeErrorBaseType):
         if (wrapped is not None):
             raise RuntimeError(f'Wrapped already wrapped; self = {self!r}, to_wrap = {to_wrap!r}.')
         
+        
+        if not isinstance(to_wrap, FunctionType):
+            raise TypeError(
+                f'Only functions and other wrappers can be wrapped; Got self = {self!r}; to_wrap = {to_wrap!r}.'
+            )
+        
         self.wrapped = to_wrap
         return self
     
@@ -170,13 +178,13 @@ class WrapperBase(RichAttributeErrorBaseType):
         return False
     
     
-    def do_revert(self):
+    def do_reverse(self):
         """
-        Tests whether the test's result should be reverted.
+        Tests whether the test's result should be reversed.
         
         Returns
         -------
-        do_revert : `bool`
+        do_reverse : `bool`
         """
         return False
     
@@ -220,7 +228,7 @@ class WrapperBase(RichAttributeErrorBaseType):
         
         Returns
         -------
-        test : `Any`
+        test : `object`
         
         Raises
         ------
@@ -275,64 +283,20 @@ class WrapperBase(RichAttributeErrorBaseType):
         return False
     
     
-    def context(self, handle):
+    def get_context(self, handle):
         """
-        Context over a test handle.
-        
-        This method is a generator.
+        Returns a context over a test handle.
         
         Parameters
         ----------
         handle : ``Handle``
-            The parent test handle.
-        
-        Yields
-        ------
-        step_result : ``Result``, ``CallState``, ``ResultState``
+            Test handle.
         
         Returns
         -------
-        step_result : ``Result``, ``CallState``, ``ResultState``
-        
-        Example Implementation
-        ----------------------
-        ```py
-        # before first yield we might check the test handle out and return a `Result` if something is wrong.
-        
-        if everything is not good:
-            return Result(handle)....
-        
-        # If we find everything good, we will get back a `CallState` on our yield
-        call_state = yield
-        
-        # We might modify the parameters of the call state with `.with_parameters` method
-        call_state = call_state.with_parameters(positional, keyword)
-        
-        # If something is wrong, we can return a `Result` again.
-        if everything is not good:
-            return Result(handle)....
-        
-        # If everything is good, we yield back our call state. At this time we will get back a `ResultState` on our
-        # yield.
-        
-        result_state = yield call_state
-        
-        # We might check the result state and modify it, or again return a `Result` if something is wrong.
-        
-        if everything is not good:
-            return Result(handle)....
-        
-        # To modify the result state, use the `.with_return` or the `.with_exception` methods.
-        result_state = result_state.with_return(None)
-        result_state = result_state.with_exception(None)
-        
-        At the end yield back our `result_state`
-        yield result_state
-        ```
+        context : ``ContextBase``
         """
-        call_state = yield None
-        result_state = yield call_state
-        yield result_state
+        return None
     
     
     def iter_environments(self):
