@@ -1,103 +1,105 @@
-__all__ = ('WrapperCall',)
+__all__ = ('WrapperCalling',)
 
 import reprlib
 
 from scarletio import copy_docs
 
+from ..contexts import ContextCalling
+from ..helpers.hashing import hash_dict, hash_set, hash_tuple, try_hash_method
+from ..helpers.un_nesting import un_nest_exceptions
 
-from ..assertions import AssertionException
-from ..helpers import hash_dict, hash_set, hash_tuple, try_hash_method, try_match_exception, un_nest_expected_exceptions
-from ..result import Result
-
-from .wrapper_conflict import WrapperConflict
 from .wrapper_base import WrapperBase
+from .wrapper_conflict import WrapperConflict
 
 
-class WrapperCall(WrapperBase):
+MODE_RAISING = 1 << 0
+MODE_RETURNING = 1 << 2
+MODE_CALL_WITH = 1 << 3
+
+
+class WrapperCalling(WrapperBase):
     """
     Combined wrapper supporting `call_with`, `returning` and `raising`.
     
     Attributes
     ----------
-    wrapped : `Any`
+    wrapped : `object`
         The wrapped test.
-    calling_keyword_parameters : `None`, `dict` of (`str`, `Any`) items
+    calling_keyword_parameters : `None`, `dict` of (`str`, `object`) items
         Keyword parameters to call the test with if ``.is_call_with``.
-    calling_positional_parameters : `None`, `tuple` of `Any`
+    calling_positional_parameters : `None`, `tuple` of `object`
         Positional parameter to call the test with if ``.is_call_with``.
-    is_raising : `bool`
-        Whether raised exceptions of the test should be checked.
-    is_returning : `bool`
-        Whether returned value of the test should be checked.
-    is_call_with : `bool`
-        Whether the test should be called with specific parameters.
+    mode : `int`
+        Bitwise flag containing the mode of calling and handling returns.
     raising_accept_subtypes : `bool`
         Whether exception subclasses are accepted as well if ``.is_raising``.
     raising_exceptions : `None`, `set` of ``BaseException``
-        The raising_exceptions expected to be raised if ``.is_raising``.
-    returning_value : `None`, `Any`
+        The raised exceptions to be expected to be raised if ``.is_raising``.
+    raising_where : `None`, `callable`
+        Additional check to check the raised exception if ``.is_raising`.
+    returning_value : `None`, `object`
         The expected returned value of the test if ``.is_returning``.
     """
     __slots__ = (
-        'calling_keyword_parameters', 'calling_positional_parameters', 'is_call_with', 'is_raising', 'is_returning',
-        'raising_exceptions', 'raising_accept_subtypes', 'returning_value'
+        'calling_keyword_parameters', 'calling_positional_parameters', 'mode', 'raising_exceptions',
+        'raising_accept_subtypes', 'raising_where', 'returning_value'
     )
     
-    def __new__(cls, wrapped=None, *, raising=None, returning=None, call_with=None):
+    def __new__(cls, wrapped = None, *, call_with = None, raising = None, returning = None):
         """
         Creates a new combined test wrapper.
         
         Parameters
         ----------
-        wrapped : `None`, `Any` = `None`, Optional
+        wrapped : `None`, `object` = `None`, Optional
             The wrapped test if any.
-        raising : `None`, `tuple` (`set` of ``BaseException``, `bool`) = `None`, Optional (Keyword only)
-            Whether the test is raising.
-        returning : `None`, `tuple` (`Any`) = `None`, Optional (Keyword only)
-            Whether the test is returning.
-        call_with : `None`, `tuple` (`tuple` of `Any`, `dict` of (`str`, `Any`) items) = `None`
+        call_with : `None`, `tuple` (`tuple` of `object`, `dict` of (`str`, `object`) items) = `None`
                 , Optional (Keyword only)
             Whether the test should be called with parameters.
+        raising : `None`, `tuple` (`set` of ``BaseException``, `bool`, (`None`, `callable`)) = `None` \
+                , Optional (Keyword only)
+            Whether the test is raising.
+        returning : `None`, `tuple` (`object`) = `None`, Optional (Keyword only)
+            Whether the test is returning.
         """
+        mode = 0
+        
         if raising is None:
-            is_raising = False
             raising_exceptions = None
             raising_accept_subtypes = None
+            raising_where = None
         
         else:
-            is_raising = True
-            raising_exceptions, raising_accept_subtypes = raising
+            mode |= MODE_RAISING
+            raising_exceptions, raising_accept_subtypes, raising_where = raising
         
         
         if returning is None:
-            is_returning = False
             returning_value = None
         
         else:
-            is_returning = True
-            returning_value = returning[0]
+            mode |= MODE_RETURNING
+            returning_value, = returning
         
         
         if call_with is None:
-            is_call_with = False
             calling_keyword_parameters = None
             calling_positional_parameters = None
         
         else:
-            is_call_with = True
+            mode |= MODE_CALL_WITH
             calling_positional_parameters, calling_keyword_parameters = call_with
         
         
         self = object.__new__(cls)
         self.wrapped = wrapped
         
-        self.raising_accept_subtypes = raising_accept_subtypes
-        self.raising_exceptions = raising_exceptions
-        self.is_raising = is_raising
-        self.is_returning = is_returning
-        self.is_call_with = is_call_with
         self.calling_keyword_parameters = calling_keyword_parameters
         self.calling_positional_parameters = calling_positional_parameters
+        self.mode = mode
+        self.raising_accept_subtypes = raising_accept_subtypes
+        self.raising_exceptions = raising_exceptions
+        self.raising_where = raising_where
         self.returning_value = returning_value
         
         return self
@@ -107,11 +109,11 @@ class WrapperCall(WrapperBase):
     def __repr__(self):
         for field_added, repr_parts in self._cursed_repr_builder():
             
+            mode = self.mode
             repr_parts.append(' (')
             type_field_added = False
             
-            is_raising = self.is_raising
-            if is_raising:
+            if mode & MODE_RAISING:
                 if type_field_added:
                     repr_parts.append(', ')
                 else:
@@ -119,9 +121,7 @@ class WrapperCall(WrapperBase):
                 
                 repr_parts.append('raising')
             
-            
-            is_returning = self.is_returning
-            if is_returning:
+            if mode & MODE_RETURNING:
                 if type_field_added:
                     repr_parts.append(', ')
                 else:
@@ -129,9 +129,7 @@ class WrapperCall(WrapperBase):
             
                 repr_parts.append('returning')
             
-            is_call_with = self.is_call_with
-            
-            if is_call_with:
+            if mode & MODE_CALL_WITH:
                 if type_field_added:
                     repr_parts.append(', ')
                 else:
@@ -142,7 +140,7 @@ class WrapperCall(WrapperBase):
             repr_parts.append(')')
             
             
-            if is_raising:
+            if mode & MODE_RAISING:
                 if field_added:
                     repr_parts.append(',')
                 else:
@@ -153,18 +151,22 @@ class WrapperCall(WrapperBase):
                 
                 repr_parts.append(', raising_accept_subtypes = ')
                 repr_parts.append(repr(self.raising_accept_subtypes))
+                
+                raising_where = self.raising_where
+                if (raising_where is not None):
+                    repr_parts.append(', raising_where = ')
+                    repr_parts.append(repr(raising_where))
             
-            if is_returning:
+            if mode & MODE_RETURNING:
                 if field_added:
                     repr_parts.append(',')
                 else:
                     field_added = True
                 
-                repr_parts.append(' self.returning_value = ')
+                repr_parts.append(', returning_value = ')
                 repr_parts.append(reprlib.repr(self.returning_value))
             
-            
-            if is_call_with:
+            if mode & MODE_CALL_WITH:
                 calling_positional_parameters = self.calling_positional_parameters
                 if calling_positional_parameters:
                     if field_added:
@@ -192,19 +194,20 @@ class WrapperCall(WrapperBase):
     def __hash__(self):
         hash_value = WrapperBase.__hash__(self)
         
-        if self.is_raising:
+        if self.is_raising():
             hash_value ^= hash_set(self.raising_exceptions)
             hash_value ^= self.raising_accept_subtypes
-        
-        if self.is_returning:
+            raising_where = self.raising_where
+            if (raising_where is not None):
+                hash_value ^= try_hash_method(raising_where)
+                
+        if self.is_returning():
             hash_value ^= try_hash_method(self.returning_value)
         
-        
-        if self.is_call_with:
+        if self.is_call_with():
             hash_value ^= hash_tuple(self.calling_positional_parameters)
             hash_value ^= hash_dict(self.calling_keyword_parameters)
         
-        
         return hash_value
     
     
@@ -213,30 +216,25 @@ class WrapperCall(WrapperBase):
         if type(self) is not type(other):
             return NotImplemented
         
-        is_raising = self.is_raising
-        if is_raising != other.is_raising:
+        self_mode = self.mode
+        if self_mode != other.mode:
             return False
         
-        if is_raising:
+        if self_mode & MODE_RAISING:
             if self.raising_exceptions != other.raising_exceptions:
                 return False
             
             if self.raising_accept_subtypes != other.raising_accept_subtypes:
                 return False
+            
+            if self.raising_where != other.raising_where:
+                return False
         
-        is_returning = self.is_returning
-        if is_returning != other.is_returning:
-            return False
-        
-        if is_returning:
+        if self_mode & MODE_RETURNING:
             if self.returning_value != other.returning_value:
                 return False
         
-        is_call_with = self.is_call_with
-        if is_call_with != other.is_call_with:
-            return False
-        
-        if is_call_with:
+        if self_mode & MODE_CALL_WITH:
             if self.calling_positional_parameters != other.calling_positional_parameters:
                 return False
             
@@ -248,7 +246,7 @@ class WrapperCall(WrapperBase):
     
     @copy_docs(WrapperBase.check_conflicts)
     def check_conflicts(self):
-        if self.is_raising and self.is_returning:
+        if self.is_raising() and self.is_returning():
             return WrapperConflict(
                 self,
                 reason = 'A call wrapper cannot be returning & raising at the same time.',
@@ -261,11 +259,11 @@ class WrapperCall(WrapperBase):
             return
         
         
-        self_input_field_count = self.is_call_with
-        self_output_field_count = self.is_raising + self.is_returning
+        self_input_field_count = self.is_call_with()
+        self_output_field_count = self.is_raising() + self.is_returning()
         
-        other_input_count = other.is_call_with
-        other_output_field_count = other.is_raising + other.is_returning
+        other_input_count = other.is_call_with()
+        other_output_field_count = other.is_raising() + other.is_returning()
         
         if (self_input_field_count + self_output_field_count) == (other_input_count + other_output_field_count):
             # Both defined input and output, so we accept both.
@@ -302,68 +300,15 @@ class WrapperCall(WrapperBase):
         if type(self) is not type(other):
             return False
         
-        if self.is_call_with and other.is_call_with:
+        if self.is_call_with() and other.is_call_with():
             return True
         
         return False
     
     
-    @copy_docs(WrapperBase.context)
-    def context(self, handle):
-        call_state = yield None
-        
-        if self.is_call_with:
-            call_state = call_state.with_parameters(
-                self.calling_positional_parameters,
-                self.calling_keyword_parameters,
-            )
-        
-        result_state = yield call_state
-        
-        # Ignore `AssertionException`-s.
-        if result_state is None:
-            raised_exception = None
-        else:
-            raised_exception = result_state.raised_exception
-        
-        if (raised_exception is None) or (not isinstance(raised_exception, AssertionException)):
-            
-            if self.is_raising:
-                raising_exceptions = self.raising_exceptions
-                raising_accept_subtypes = self.raising_accept_subtypes
-                if raised_exception is None:
-                    return Result(handle).with_exception(
-                        raising_exceptions,
-                        None,
-                        raising_accept_subtypes,
-                    )
-                
-                if try_match_exception(raising_exceptions, raised_exception, raising_accept_subtypes):
-                    if (result_state is not None):
-                        result_state = result_state.with_exception(None)
-                
-                else:
-                    return Result(handle).with_exception(
-                        raising_exceptions,
-                        raised_exception,
-                        raising_accept_subtypes,
-                    )
-            
-            elif self.is_returning:
-                if (raised_exception is not None):
-                    return Result(handle).with_exception(None, raised_exception, False)
-                
-                if (result_state is None):
-                    returned_value = None
-                else:
-                    returned_value = result_state.returned_value
-                
-                returning_value = self.returning_value
-                
-                if returned_value != returning_value:
-                    return Result(handle).with_return(returning_value, returned_value)
-        
-        yield result_state
+    @copy_docs(WrapperBase.get_context)
+    def get_context(self, handle):
+        return ContextCalling(handle, self)
     
     
     @property
@@ -373,10 +318,10 @@ class WrapperCall(WrapperBase):
         
         Returns
         -------
-        raising_key : `None`, `tuple` (`set` of ``BaseException``, `bool`)
+        raising_key : `None`, `tuple` (`set` of ``BaseException``, `bool`, (`None`, `callable`))
         """
-        if self.is_raising:
-            return (self.raising_exceptions, self.raising_accept_subtypes)
+        if self.is_raising():
+            return (self.raising_exceptions, self.raising_accept_subtypes, self.raising_where)
     
     
     @property
@@ -386,9 +331,9 @@ class WrapperCall(WrapperBase):
         
         Returns
         -------
-        raising_key : `None`, `tuple` (`set` of ``BaseException``, `bool`)
+        returning_key : `None`, `tuple` (`object`)
         """
-        if self.is_raising:
+        if self.is_returning():
             return (self.returning_value, )
     
     
@@ -399,23 +344,27 @@ class WrapperCall(WrapperBase):
         
         Returns
         -------
-        call_with_key : `None`, `tuple` (`tuple` of `Any`, `dict` of (`str`, `Any`) items)
+        call_with_key : `None`, `tuple` (`tuple` of `object`, `dict` of (`str`, `object`) items)
         """
-        if self.is_call_with:
+        if self.is_call_with():
             return (self.calling_positional_parameters, self.calling_keyword_parameters)
     
     
     @classmethod
-    def raising_constructor(cls,  *exception_types, raising_accept_subtypes = True):
+    def raising_constructor(cls, exception_type, *exception_types, accept_subtypes = True, where = None):
         """
         Creates a new raising wrapper.
         
         Parameters
         ----------
-        *exception_types : tuple` of (`BaseException`, ...)
-            Exception types to expect.
-        raising_accept_subtypes : `bool` = `True`
+        exception_type : `type<BaseException> | BaseException>
+            Exception type to expect.
+        *exception_types : `tuple<type<BaseException>, BaseException, ...>`
+            Additional exception types.
+        accept_subtypes : `bool` = `True`
             Whether subclasses are accepted as well.
+        where : `None`, `callable` = `None`, Optional (Keyword only)
+            Additional check to check the raised exception.
         
         Raises
         ------
@@ -426,29 +375,37 @@ class WrapperCall(WrapperBase):
         
         Returns
         -------
-        new : ``WrapperCall``
+        self : `instance<self>`
         """
-        exception_types = un_nest_expected_exceptions(exception_types)
+        exception_types = un_nest_exceptions((exception_type, *exception_types))
         if not exception_types:
             raise ValueError(
                 'At least 1 exception is required.'
             )
         
         return cls(
-            raising = (exception_types, raising_accept_subtypes),
+            raising = (exception_types, accept_subtypes, where),
         )
     
     
-    def raising(self,  *exception_types, raising_accept_subtypes = True):
+    def raising(self, exception_type, *exception_types, accept_subtypes = True, where = None):
         """
         Creates a new raising wrapper extending self.
         
         Parameters
         ----------
-        *exception_types : tuple` of (`BaseException`, ...)
-            Exception types to expect.
-        raising_accept_subtypes : `bool` = `True`
+        exception_type : `type<BaseException> | BaseException>
+            Exception type to expect.
+        *exception_types : `tuple<type<BaseException>, BaseException, ...>`
+            Additional exception types.
+        accept_subtypes : `bool` = `True`
             Whether subclasses are accepted as well.
+        where : `None`, `callable` = `None`, Optional (Keyword only)
+            Additional check to check the raised exception.
+        
+        Returns
+        -------
+        new : `instance<type<self>>`
         
         Raises
         ------
@@ -456,12 +413,8 @@ class WrapperCall(WrapperBase):
             If an `exception_types`'s type is incorrect.
         ValueError
             If no exception was passed.
-        
-        Returns
-        -------
-        new : ``WrapperCall``
         """
-        exception_types = un_nest_expected_exceptions(exception_types)
+        exception_types = un_nest_exceptions((exception_type, *exception_types))
         if not exception_types:
             raise ValueError(
                 'At least 1 exception is required.'
@@ -469,7 +422,7 @@ class WrapperCall(WrapperBase):
         
         return type(self)(
             self.wrapped,
-            raising = (exception_types, raising_accept_subtypes),
+            raising = (exception_types, accept_subtypes, where),
             returning = self.returning_key,
             call_with = self.call_with_key,
         )
@@ -482,12 +435,12 @@ class WrapperCall(WrapperBase):
         
         Parameters
         ----------
-        returning : `Any`
+        returning : `object`
             The expected value to be returned.
         
         Returns
         -------
-        self : ``WrapperCall``
+        self : `instance<self>`
         """
         return cls(
             returning = (returning, ),
@@ -500,12 +453,12 @@ class WrapperCall(WrapperBase):
         
         Parameters
         ----------
-        returning_value : `Any`
+        returning_value : `object`
             The expected value to be returned.
         
         Returns
         -------
-        new : ``WrapperCall``
+        new : `instance<type<self>>`
         """
         return type(self)(
             self.wrapped,
@@ -525,16 +478,16 @@ class WrapperCall(WrapperBase):
         
         Returns
         -------
-        new : ``WrapperCall``
+        new : `instance<type<self>>`
         
         Raises
         ------
         ValueError
             The wrapper is not parameterised, or incorrect amount parameters registered.
         """
-        if not self.is_call_with:
+        if not self.is_call_with():
             raise ValueError(
-                f'Call wrapper cannot check for return value if it has no parameters added; self={self!r}.'
+                f'Call wrapper cannot check for return value if it has no parameters added; self = {self!r}.'
             )
         
         calling_positional_parameters = self.calling_positional_parameters
@@ -561,16 +514,16 @@ class WrapperCall(WrapperBase):
         
         Returns
         -------
-        new : ``WrapperCall``
+        new : `instance<type<self>>`
         
         Raises
         ------
         ValueError
             The wrapper is not parameterised, or incorrect amount parameters registered.
         """
-        if not self.is_call_with:
+        if not self.is_call_with():
             raise ValueError(
-                f'Call wrapper cannot check for return value if it has no parameters added; self={self!r}.'
+                f'Call wrapper cannot check for return value if it has no parameters added; self = {self!r}.'
             )
         
         calling_positional_parameters = self.calling_positional_parameters
@@ -578,8 +531,8 @@ class WrapperCall(WrapperBase):
         
         if len(calling_positional_parameters) + len(calling_keyword_parameters) != 1:
             raise ValueError(
-                f'``.returning_itself`` is only applicable if the wrapper has 1 parameter added; '
-                f'self={self!r}.'
+                f'`returning_itself` is only applicable if the wrapper has 1 parameter added; '
+                f'self = {self!r}.'
             )
         
         if calling_positional_parameters:
@@ -602,14 +555,14 @@ class WrapperCall(WrapperBase):
         
         Parameters
         ----------
-        *calling_positional_parameters : `tuple` of `Any`
+        *calling_positional_parameters : `tuple` of `object`
             Positional parameter to call the test with.
-        **calling_keyword_parameters : `dict` of (`str`, `Any`) items
+        **calling_keyword_parameters : `dict` of (`str`, `object`) items
             Keyword parameters to call the test with.
         
         Returns
         -------
-        self : ``WrapperCall``
+        self : `instance<cls>`
         """
         return cls(
             call_with = (calling_positional_parameters, calling_keyword_parameters),
@@ -622,14 +575,14 @@ class WrapperCall(WrapperBase):
         
         Parameters
         ----------
-        *calling_positional_parameters : `tuple` of `Any`
+        *calling_positional_parameters : `tuple` of `object`
             Positional parameter to call the test with.
-        **calling_keyword_parameters : `dict` of (`str`, `Any`) items
+        **calling_keyword_parameters : `dict` of (`str`, `object`) items
             Keyword parameters to call the test with.
         
         Returns
         -------
-        new : ``WrapperCall``
+        new : `instance<type<self>>`
         """
         return type(self)(
             self.wrapped,
@@ -637,3 +590,36 @@ class WrapperCall(WrapperBase):
             returning = self.returning_key,
             call_with = (calling_positional_parameters, calling_keyword_parameters),
         )
+    
+    
+    def is_raising(self):
+        """
+        Returns whether raised exceptions of the test should be checked.
+        
+        Returns
+        -------
+        is_raising : `bool`
+        """
+        return True if self.mode & MODE_RAISING else False
+    
+    
+    def is_returning(self):
+        """
+        Returns whether returned value of the test should be checked.
+        
+        Returns
+        -------
+        is_returning : `bool`
+        """
+        return True if self.mode & MODE_RETURNING else False
+    
+    
+    def is_call_with(self):
+        """
+        Returns whether the test should be called with specific parameters.
+        
+        Returns
+        -------
+        is_call_with : `bool`
+        """
+        return True if self.mode & MODE_CALL_WITH else False
